==> fasc-openapi-java-sdk-5.2.9.2-sources.jar: com/fasc/open/api/v5_1/req/seal/GetSealListReq.java <==
package com.fasc.open.api.v5_1.req.seal;

import com.fasc.open.api.bean.base.BaseReq;

import java.util.List;

/**
 * @author gongj
 * @date 2022/7/13
 */
public class GetSealListReq extends BaseReq {

    private String ownerId;
    private String openCorpId;
    private String grantFreeSign;
    private SealListFilter listFilter;
    public static class SealListFilter {
        List<String> categoryType;

        List<String> sealTags;

        public List<String> getCategoryType() {
            return categoryType;
        }

        public void setCategoryType(List<String> categoryType) {
            this.categoryType = categoryType;
        }

        public List<String> getSealTags() {
            return sealTags;
        }

        public void setSealTags(List<String> sealTags) {
            this.sealTags = sealTags;
        }
    }
    @Deprecated
    public String getOwnerId() {
        return ownerId;
    }
    @Deprecated
    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getGrantFreeSign() {
        return grantFreeSign;
    }

    public void setGrantFreeSign(String grantFreeSign) {
        this.grantFreeSign = grantFreeSign;
    }

    public SealListFilter getListFilter() {
        return listFilter;
    }

    public void setListFilter(SealListFilter listFilter) {
        this.listFilter = listFilter;
    }
}

==> fasc-openapi-java-sdk-5.7.2.0815-sources.jar: com/fasc/open/api/v5_1/req/seal/GetSealListReq.java <==
package com.fasc.open.api.v5_1.req.seal;

import com.fasc.open.api.bean.base.BaseReq;

import java.util.List;

/**
 * @author gongj
 * @date 2022/7/13
 */
public class GetSealListReq extends BaseReq {

    private String ownerId;
    private String openCorpId;
    private String entityId;
    private String grantFreeSign;
    private SealListFilter listFilter;

    private Integer listPageNo;
    private Integer listPageSize;

    public Integer getListPageNo() {
        return listPageNo;
    }

    public void setListPageNo(Integer listPageNo) {
        this.listPageNo = listPageNo;
    }

    public Integer getListPageSize() {
        return listPageSize;
    }

    public void setListPageSize(Integer listPageSize) {
        this.listPageSize = listPageSize;
    }

    public String getEntityId() {
        return entityId;
    }

    public void setEntityId(String entityId) {
        this.entityId = entityId;
    }

    public static class SealListFilter {
        List<String> categoryType;

        List<String> sealTags;

        public List<String> getCategoryType() {
            return categoryType;
        }

        public void setCategoryType(List<String> categoryType) {
            this.categoryType = categoryType;
        }

        public List<String> getSealTags() {
            return sealTags;
        }

        public void setSealTags(List<String> sealTags) {
            this.sealTags = sealTags;
        }
    }
    @Deprecated
    public String getOwnerId() {
        return ownerId;
    }
    @Deprecated
    public void setOwnerId(String ownerId) {
        this.ownerId = ownerId;
    }

    public String getOpenCorpId() {
        return openCorpId;
    }

    public void setOpenCorpId(String openCorpId) {
        this.openCorpId = openCorpId;
    }

    public String getGrantFreeSign() {
        return grantFreeSign;
    }

    public void setGrantFreeSign(String grantFreeSign) {
        this.grantFreeSign = grantFreeSign;
    }

    public SealListFilter getListFilter() {
        return listFilter;
    }

    public void setListFilter(SealListFilter listFilter) {
        this.listFilter = listFilter;
    }
}
